@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 # created by Tobias Powalowski <tpowa@archlinux.org>
-source /usr/lib/archboot/functions
-source /usr/lib/archboot/iso_functions
+. /usr/lib/archboot/common.sh
+. /usr/lib/archboot/iso.sh
 [[ -z "${1}" ]] && _usage
 _parameters "$@"
 _root_check
