@@ -29,7 +29,7 @@ usage () {
     echo -e "                  This operation needs at least \033[1m3.2 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-latest-image\033[0m    Generate latest image files in /archboot directory"
-    echo -e "                  This operation needs at least \033[1m5.0 GB RAM\033[0m."
+    echo -e "                  This operation needs at least \033[1m3.9 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
     echo -e "                  This operation needs at least \033[1m3.5 GB RAM\033[0m."
@@ -99,7 +99,7 @@ _umount_w_dir() {
 _zram_mount() {
     # add defaults
     _ZRAM_ALGORITHM=${_ZRAM_ALGORITHM:-"zstd"}
-    modprobe zram 2>/dev/null
+    modprobe zram > /dev/tty7 2>&1
     echo "${_ZRAM_ALGORITHM}" >/sys/block/zram0/comp_algorithm
     echo "${1}" >/sys/block/zram0/disksize
     echo "Creating btrfs filesystem with ${_DISKSIZE} on /dev/zram0 ..." > /dev/tty7
@@ -109,7 +109,7 @@ _zram_mount() {
     # (online fstrimming the block device!)
     # fstrim <mountpoint> for manual action
     # it needs some seconds to get RAM free on delete!
-    mount -o discard /dev/zram0 "${_W_DIR}"
+    mount -o discard /dev/zram0 "${_W_DIR}" > /dev/tty7 2>&1
 }
 
 _clean_archboot() {
@@ -230,64 +230,226 @@ _kexec() {
         sleep 1
     done
 }
-_cleanup_xfce() {
-    echo "Cleanup archboot environment ..."
+
+_cleanup_install() {
     rm -rf /usr/share/{man,info,doc,gtk-doc,ibus,perl5}
     rm -rf /usr/include
     rm -rf /usr/lib/libgo.*
 }
 
-_launch_xfce() {
-    X_PACKAGES="llvm-libs gcc-libs perl glibc xorg libtiff glib2 chromium libcups harfbuzz \
-    avahi nss breeze-icons tigervnc p11-kit libp11-kit gvfs fuse tpm2-tss \
-    libsecret gparted gvfs-smb smbclient libcap tevent libbsd libldap tdb ldb \
-    libmd jansson libsasl xfce4 thunar-archive-plugin thunar-volman file-roller \
-    nss-mdns gnome-keyring"
-    # try to save RAM by calling the cleanup hook and installing each package alone
+_prepare_xfce() {
+    # fix libs first, then install packages from defaults
+    _XORG="${_FULL_PACKAGES} ${_X_PACKAGES}"
+    # saving RAM by calling always cleanup hook and installing each package alone
     if [[ -e /var/cache/pacman/pkg/archboot.db ]]; then
-        echo "Install packages ..."
+        echo "Running pacman to install packages: ${_FULL_PACKAGES} ${_X_PACKAGES} ..."
         _INSTALL_SOURCE="file:///var/cache/pacman/pkg"
         _create_pacman_conf
-        pacman -Sy --config ${_PACMAN_CONF}
-        for i in ${X_PACKAGES}; do
+        #shellcheck disable=SC2086
+        pacman -Sy --config ${_PACMAN_CONF} >/dev/null 2>&1 || exit 1
+        for i in ${_XORG}; do
             #shellcheck disable=SC2086
-            pacman -S ${i} --config ${_PACMAN_CONF} --noconfirm || exit 1
-            _cleanup_xfce
+            pacman -S ${i} --config ${_PACMAN_CONF} --noconfirm >/dev/null 2>&1 || exit 1
+            _cleanup_install
         done
     else
-        echo "Updating environment ..."
-        pacman -Syu --ignore linux --ignore linux-firmware --ignore linux-firmware-marvell --noconfirm || exit 1
-        _clean_xfce
-        echo "Install packages ..."
-        for i in ${X_PACKAGES}; do
+        echo "Updating environment to latest packages (ignoring packages: ${_X_IGNORE}) ..."
+        _IGNORE=""
+        if [[ -n "${_X_IGNORE}" ]]; then
+            for i in ${_X_IGNORE}; do
+                _IGNORE="${_IGNORE} --ignore ${i}"
+            done
+        fi
+        #shellcheck disable=SC2086
+        pacman -Syu ${_IGNORE} --noconfirm >/dev/null 2>&1 || exit 1
+        _cleanup_install
+        echo "Running pacman to install packages: ${_FULL_PACKAGES} ${_X_PACKAGES} ..."
+        for i in ${_XORG}; do
             #shellcheck disable=SC2086
-            pacman -S ${i} --noconfirm || exit 1
-            _clean_xfce
+            pacman -S ${i} --noconfirm >/dev/null 2>&1 || exit 1
+            _cleanup_install
         done
     fi
-    # fix locale
-    echo "Fix locale ..."
+    echo "Removing files from cache directory: ${_X_RM_PACKAGES} ..."
+    for i in ${_X_RM_PACKAGES}; do
+        rm -f /var/cache/pacman/pkg/"${i}"-*
+    done
+    echo "Removing firmware files ..."
+    rm -rf /usr/lib/firmware
+    echo "Recreating C.UTF-8 locale ..."
     sed -i -e 's:#C.UTF-8 UTF-8:C.UTF-8 UTF-8:g' "${1}/etc/locale.gen"
-    locale-gen
+    locale-gen >/dev/null 2>&1
+    echo "Cleanup locale and i18n ..."
     rm -rf /usr/share/{locale,i18n}
-    # replace appfinder with archboot setup
-    sed -i -e 's#xfce4-appfinder#archboot#g' /etc/xdg/xfce4/panel/default.xml
-    echo "Fix chromium startup ..."
-    # fix chromium startup
+}
+
+_configure_xfce() {
+    echo "Configuring xfce panel ..."
+    cat << EOF >/etc/xdg/xfce4/panel/default.xml
+<?xml version="1.0" encoding="UTF-8"?>
+
+<channel name="xfce4-panel" version="1.0">
+  <property name="configver" type="int" value="2"/>
+  <property name="panels" type="array">
+    <value type="int" value="1"/>
+    <value type="int" value="2"/>
+    <property name="dark-mode" type="bool" value="true"/>
+    <property name="panel-1" type="empty">
+      <property name="position" type="string" value="p=6;x=0;y=0"/>
+      <property name="length" type="uint" value="100"/>
+      <property name="position-locked" type="bool" value="true"/>
+      <property name="icon-size" type="uint" value="16"/>
+      <property name="size" type="uint" value="26"/>
+      <property name="plugin-ids" type="array">
+        <value type="int" value="1"/>
+        <value type="int" value="2"/>
+        <value type="int" value="3"/>
+        <value type="int" value="4"/>
+        <value type="int" value="5"/>
+        <value type="int" value="6"/>
+        <value type="int" value="7"/>
+        <value type="int" value="8"/>
+        <value type="int" value="9"/>
+        <value type="int" value="10"/>
+        <value type="int" value="11"/>
+        <value type="int" value="12"/>
+        <value type="int" value="13"/>
+        <value type="int" value="14"/>
+      </property>
+    </property>
+    <property name="panel-2" type="empty">
+      <property name="autohide-behavior" type="uint" value="1"/>
+      <property name="position" type="string" value="p=10;x=0;y=0"/>
+      <property name="length" type="uint" value="1"/>
+      <property name="position-locked" type="bool" value="true"/>
+      <property name="size" type="uint" value="48"/>
+      <property name="plugin-ids" type="array">
+        <value type="int" value="15"/>
+        <value type="int" value="16"/>
+        <value type="int" value="17"/>
+        <value type="int" value="18"/>
+        <value type="int" value="19"/>
+        <value type="int" value="20"/>
+        <value type="int" value="21"/>
+        <value type="int" value="22"/>
+      </property>
+    </property>
+  </property>
+  <property name="plugins" type="empty">
+    <property name="plugin-1" type="string" value="applicationsmenu"/>
+    <property name="plugin-2" type="string" value="tasklist">
+      <property name="grouping" type="uint" value="1"/>
+    </property>
+    <property name="plugin-3" type="string" value="separator">
+      <property name="expand" type="bool" value="true"/>
+      <property name="style" type="uint" value="0"/>
+    </property>
+    <property name="plugin-4" type="string" value="pager"/>
+    <property name="plugin-5" type="string" value="separator">
+        <property name="style" type="uint" value="0"/>
+    </property>
+    <property name="plugin-6" type="string" value="systray">
+        <property name="square-icons" type="bool" value="true"/>
+    </property>
+    <property name="plugin-8" type="string" value="pulseaudio">
+      <property name="enable-keyboard-shortcuts" type="bool" value="true"/>
+      <property name="show-notifications" type="bool" value="true"/>
+    </property>
+    <property name="plugin-9" type="string" value="power-manager-plugin"/>
+    <property name="plugin-10" type="string" value="notification-plugin"/>
+    <property name="plugin-11" type="string" value="separator">
+      <property name="style" type="uint" value="0"/>
+    </property>
+    <property name="plugin-12" type="string" value="clock"/>
+    <property name="plugin-13" type="string" value="separator">
+      <property name="style" type="uint" value="0"/>
+    </property>
+    <property name="plugin-14" type="string" value="actions"/>
+    <property name="plugin-15" type="string" value="showdesktop"/>
+    <property name="plugin-16" type="string" value="separator"/>
+    <property name="plugin-17" type="string" value="launcher">
+      <property name="items" type="array">
+        <value type="string" value="xfce4-terminal-emulator.desktop"/>
+      </property>
+    </property>
+    <property name="plugin-18" type="string" value="launcher">
+      <property name="items" type="array">
+        <value type="string" value="xfce4-file-manager.desktop"/>
+      </property>
+    </property>
+    <property name="plugin-19" type="string" value="launcher">
+      <property name="items" type="array">
+        <value type="string" value="xfce4-web-browser.desktop"/>
+      </property>
+    </property>
+    <property name="plugin-20" type="string" value="launcher">
+      <property name="items" type="array">
+        <value type="string" value="gparted.desktop"/>
+      </property>
+    </property>
+    <property name="plugin-21" type="string" value="separator"/>
+    <property name="plugin-22" type="string" value="launcher">
+      <property name="items" type="array">
+        <value type="string" value="archboot.desktop"/>
+      </property>
+    </property>
+  </property>
+</channel>
+EOF
+    echo "Setting breeze as default icons..."
+    sed -i -e 's#<property name="IconThemeName" type="string" value="Adwaita"/>#<property name="IconThemeName" type="string" value="breeze"/>#g' \
+    /etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xsettings.xml
+    echo "Setting archboot background image ..."
+    cat << EOF >/etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-desktop.xml
+<?xml version="1.0" encoding="UTF-8"?>
+
+<channel name="xfce4-desktop" version="1.0">
+  <property name="backdrop" type="empty">
+    <property name="screen0" type="empty">
+      <property name="monitor0" type="empty">
+        <property name="image-path" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="last-single-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        <property name="image-show" type="bool" value="true"/>
+        <property name="image-style" type="int" value="0"/>
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+      <property name="monitorVNC-0" type="empty">
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+      <property name="monitorHDMI1" type="empty">
+        <property name="workspace0" type="empty">
+          <property name="color-style" type="int" value="0"/>
+          <property name="image-style" type="int" value="3"/>
+          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
+        </property>
+      </property>
+    </property>
+  </property>
+</channel>
+EOF
+    echo "Replacing appfinder launcher with gparted ..."
+    sed -i -e 's#xfce4-appfinder#gparted#g' /etc/xdg/xfce4/panel/default.xml
+    echo "Replacing directory menu launcher with setup ..."
+    sed -i -e 's#directorymenu#archboot#g' /etc/xdg/xfce4/panel/default.xml
+    echo "Setting chromium as default browser ..."
+    sed -i -e 's#firefox#chromium#g' /etc/xdg/xfce4/helpers.rc
+    echo "Adding chromium flags to /etc/chromium-flags.conf ..."
     cat << EOF >/etc/chromium-flags.conf
 --no-sandbox
 --test-type
+--incognito
 wiki.archlinux.org/title/Archboot
 EOF
-    echo "Fix xfce4 defaults ..."
-    # fix xfce4 defaults
-    # breeze icons
-    sed -i -e 's#<property name="IconThemeName" type="string" value="Adwaita"/>#<property name="IconThemeName" type="string" value="breeze"/>#g' \
-    /etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xsettings.xml
-    sed -i -e 's#firefox#chromium#g' /etc/xdg/xfce4/helpers.rc
-    # fix gparted.desktop
-    sed -i -e 's#Categories=.*#Categories=X-Xfce-Toplevel;#g' /usr/share/applications/gparted.desktop
-    # xfce menu
+    echo "Replacing menu structure ..."
     cat << EOF >/etc/xdg/menus/xfce-applications.menu
 <!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
   "http://www.freedesktop.org/standards/menu-spec/1.0/menu.dtd">
@@ -344,48 +506,13 @@ EOF
 
 </Menu>
 EOF
-    # background image
-    cat << EOF >/etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-desktop.xml
-<?xml version="1.0" encoding="UTF-8"?>
-
-<channel name="xfce4-desktop" version="1.0">
-  <property name="backdrop" type="empty">
-    <property name="screen0" type="empty">
-      <property name="monitor0" type="empty">
-        <property name="image-path" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        <property name="last-single-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        <property name="image-show" type="bool" value="true"/>
-        <property name="image-style" type="int" value="0"/>
-        <property name="workspace0" type="empty">
-          <property name="color-style" type="int" value="0"/>
-          <property name="image-style" type="int" value="3"/>
-          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        </property>
-      </property>
-      <property name="monitorVNC-0" type="empty">
-        <property name="workspace0" type="empty">
-          <property name="color-style" type="int" value="0"/>
-          <property name="image-style" type="int" value="3"/>
-          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        </property>
-      </property>
-      <property name="monitorHDMI1" type="empty">
-        <property name="workspace0" type="empty">
-          <property name="color-style" type="int" value="0"/>
-          <property name="image-style" type="int" value="3"/>
-          <property name="last-image" type="string" value="/usr/share/archboot/grub/archboot-background.png"/>
-        </property>
-      </property>
-    </property>
-  </property>
-</channel>
-EOF
-    # hide menu entries
-    for i in xfce4-mail-reader xfce4-about; do
+    echo "Adding gparted to xfce top level menu ..."
+    sed -i -e 's#Categories=.*#Categories=X-Xfce-Toplevel;#g' /usr/share/applications/gparted.desktop
+    echo "Hiding ${_HIDE_MENU} menu entries ..."
+    for i in ${_HIDE_MENU}; do
         echo 'NoDisplay=true' >> /usr/share/applications/$i.desktop
     done
-    echo "Autostart setup ..."
+    echo "Autostarting setup ..."
     cat << EOF > /etc/xdg/autostart/archboot.desktop
 [Desktop Entry]
 Type=Application
@@ -394,18 +521,14 @@ Exec=xfce4-terminal -x /usr/bin/setup
 Icon=system-software-install
 Categories=X-Xfce-Toplevel;
 EOF
-echo "Set VNC password ..."
-echo 'archboot' | vncpasswd -f > /etc/tigervnc/passwd
-    echo "Autostart tigervnc ..."
+    cp /etc/xdg/autostart/archboot.desktop /usr/share/applications/archboot.desktop
+    echo "Autostarting tigervnc ..."
     cat << EOF > /etc/xdg/autostart/tigervnc.desktop
 [Desktop Entry]
 Type=Application
 Name=Tigervnc
 Exec=x0vncserver -rfbauth /etc/tigervnc/passwd
 EOF
-    cp /etc/xdg/autostart/archboot.desktop /usr/share/applications/archboot.desktop
-    echo "Starting avahi-daemon ..."
-    systemctl start avahi-daemon.service
-    echo "Launching XFCE ..."
-    startxfce4
+    echo "Setting VNC password /etc/tigervnc/passwd to ${_VNC_PW} ..."
+    echo "${_VNC_PW}" | vncpasswd -f > /etc/tigervnc/passwd
 }
